severity = 3
verbose  = 9
exclude  = ValuesAndExpressions::ProhibitVersionStrings ValuesAndExpressions::ProhibitConstantPragma TestingAndDebugging::ProhibitNoStrict Subroutines::ProhibitSubroutinePrototypes
include  = Variables::ProhibitPackageVars
